bayespy.nodes.CategoricalMarkovChain.initialize_from_parameters
===============================================================

.. currentmodule:: bayespy.nodes

.. automethod:: CategoricalMarkovChain.initialize_from_parameters